census_changes

Function census_changes 

pub fn census_changes(root: &Path) -> Result<Vec<Change>, ValidateError>
The differences between the committed reports and the accepted census; every row is added when none is accepted yet.

Errors

As take_census and read_accepted.