#[non_exhaustive]pub enum FlightMetric {
Apogee,
MaxSpeed,
MaxAcceleration,
MaxMach,
TimeToApogee,
FlightTime,
RodClearanceSpeed,
RodClearanceStability,
DeploymentSpeed,
GroundHitSpeed,
OptimumDelay,
}Expand description
A summary quantity of one flight.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Apogee
The highest point above the launch site, m.
MaxSpeed
The largest speed, m/s.
MaxAcceleration
The largest acceleration, m/s².
MaxMach
The largest Mach number.
TimeToApogee
The time from launch to apogee, s.
FlightTime
The time from launch to the end of the flight, s.
RodClearanceSpeed
The speed as the rocket leaves the launch rod or rail, m/s.
RodClearanceStability
The static stability margin as the rocket leaves the launch rod or rail, calibres.
DeploymentSpeed
The speed at a recovery device’s deployment, m/s.
GroundHitSpeed
The speed at ground hit, m/s.
OptimumDelay
The motor delay that would fire the ejection charge at apogee, s. OpenRocket 24.12’s
optimumdelay is not always apogee less burnout; see definition.
Implementations
Sourceimpl FlightMetric
impl FlightMetric