#[non_exhaustive]pub enum Withheld {
DefinitionUnmeasured,
ReferenceAborted,
NoEventInEither {
event: Event,
},
}Expand description
Why a metric was not compared, when that is no fault of either flight.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DefinitionUnmeasured
What the metric means in the reference’s tool and version has not been measured.
ReferenceAborted
The reference’s flight was aborted.
NoEventInEither
The event the metric is taken at happened in neither flight.