pub fn fly(
root: &Path,
flight: &RealFlight,
) -> Result<FlightRow, RealFlightError>Expand description
Flies one flight and compares it with its log.
Errors
RealFlightError if a file is missing or doesn’t read, or hpr can’t fly it.
pub fn fly(
root: &Path,
flight: &RealFlight,
) -> Result<FlightRow, RealFlightError>Flies one flight and compares it with its log.
RealFlightError if a file is missing or doesn’t read, or hpr can’t fly it.