pub struct NotReproduced(pub String);Expand description
Why a run does not reproduce a committed report (Report::reproduces): the first difference
found, in words.
Tuple Fields
0: StringTrait Implementations
Sourceimpl Clone for NotReproduced
impl Clone for NotReproduced
Sourcefn clone(&self) -> NotReproduced
fn clone(&self) -> NotReproduced
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for NotReproduced
impl Debug for NotReproduced
Sourceimpl Display for NotReproduced
impl Display for NotReproduced
impl Eq for NotReproduced
Sourceimpl Error for NotReproduced
impl Error for NotReproduced
1.30.0 · Sourcefn source(&self) -> Option<&(dyn Error + 'static)>
fn source(&self) -> Option<&(dyn Error + 'static)>
Returns the lower-level source of this error, if any. Read more
1.0.0 · Sourcefn description(&self) -> &str
fn description(&self) -> &str
👎Deprecated since 1.42.0:
use the Display impl or to_string()
Sourceimpl PartialEq for NotReproduced
impl PartialEq for NotReproduced
Sourcefn eq(&self, other: &NotReproduced) -> bool
fn eq(&self, other: &NotReproduced) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for NotReproduced