#[non_exhaustive]pub enum ValidateError {
Io {
what: &'static str,
path: String,
source: Error,
},
Toml {
path: String,
source: Box<Error>,
},
Json {
path: String,
source: Box<Error>,
},
Case(String),
Flight {
case: String,
what: String,
source: Option<Box<SimError>>,
},
}Expand description
What can go wrong running a case.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Io
A file could not be read or written.
Toml
A case or lock file could not be parsed.
Json
A reference or design file could not be parsed.
Case(String)
The case, the lock and the references disagree.
Flight
The flight itself failed, or was refused before it started.
Implementations