SeriesRow

Type Alias SeriesRow 

pub type SeriesRow = (f64, f64, f64);
One instant of a trajectory: time since ignition, height of the center of dry mass above where it started, and its speed, s, m and m/s.